@@ -10,11 +10,9 @@ pub type Arange<T> = LinSpace<T>;
 ///
 /// ```
 /// use iter_num_tools::arange;
-/// use itertools::Itertools;
 ///
 /// let it = arange(0.0..2.0, 0.5);
-/// println!("{:?}", it);
-/// itertools::assert_equal(it, vec![0.0, 0.5, 1.0, 1.5])
+/// assert!(it.eq(vec![0.0, 0.5, 1.0, 1.5]));
 /// ```
 pub fn arange<R, F>(range: R, step: F) -> Arange<F>
 where
@@ -56,6 +54,6 @@ mod tests {
     #[test]
     fn test_arange() {
         let it = arange(0.0..2.0, 0.5);
-        itertools::assert_equal(it, [0.0, 0.5, 1.0, 1.5]);
+        assert!(it.eq(vec![0.0, 0.5, 1.0, 1.5]));
     }
 }
