@@ -1,8 +1,5 @@
 #![deny(missing_docs)]
-#![allow(incomplete_features)]
-#![feature(impl_trait_in_bindings)]
-#![feature(min_type_alias_impl_trait)]
-#![feature(trusted_len)]
+#![cfg_attr(feature = "trusted_len", feature(trusted_len))]
 //! `iter_num_tools` is a collection if iterator extensions that
 //! make heavy use of number properties.
 //! Mostly extending on [Range](std::ops::Range).
@@ -15,11 +12,11 @@
 //!
 //! // Count from 1.0 up to and including 5.0, with 5 numbers counted in total
 //! let it = lin_space(1.0..=5.0, 5);
-//! assert!(it.eq([1.0, 2.0, 3.0, 4.0, 5.0]));
+//! assert!(it.eq(vec![1.0, 2.0, 3.0, 4.0, 5.0]));
 //!
 //! // Count from 0.0 up to and excluding 5.0, with 5 numbers counted in total
 //! let it = lin_space(0.0..5.0, 5);
-//! assert!(it.eq([0.0, 1.0, 2.0, 3.0, 4.0]));
+//! assert!(it.eq(vec![0.0, 1.0, 2.0, 3.0, 4.0]));
 //! ```
 //!
 //!
@@ -33,7 +30,7 @@
 //! // from 0.0 up to 1.0 in the x direction with 2 even steps,
 //! // and 0.0 up to 2.0 in the y direction with 4 even steps
 //! let it = grid_space([0.0, 0.0]..[1.0, 2.0], [2, 4]);
-//! assert!(it.eq([
+//! assert!(it.eq(vec![
 //!     [0.0, 0.0], [0.0, 0.5], [0.0, 1.0], [0.0, 1.5],
 //!     [0.5, 0.0], [0.5, 0.5], [0.5, 1.0], [0.5, 1.5],
 //! ]));
@@ -42,7 +39,7 @@
 //! // from 0.0 up to 1.0 in the x direction,
 //! // and 0.0 up to 2.0 in the y direction with 3 even steps in all directions
 //! let it = grid_space([0.0, 0.0]..=[1.0, 2.0], 3);
-//! assert!(it.eq([
+//! assert!(it.eq(vec![
 //!     [0.0, 0.0], [0.0, 1.0], [0.0, 2.0],
 //!     [0.5, 0.0], [0.5, 1.0], [0.5, 2.0],
 //!     [1.0, 0.0], [1.0, 1.0], [1.0, 2.0],
@@ -57,7 +54,7 @@
 //! use iter_num_tools::arange;
 //!
 //! let it = arange(0.0..2.0, 0.5);
-//! assert!(it.eq([0.0, 0.5, 1.0, 1.5]));
+//! assert!(it.eq(vec![0.0, 0.5, 1.0, 1.5]));
 //! ```
 //!
 //! #### Note
@@ -82,7 +79,7 @@
 //! // and 0.0 up to 2.0 in the y direction,
 //! // stepping by 0.5 each time
 //! let it = arange_grid([0.0, 0.0]..[1.0, 2.0], 0.5);
-//! assert!(it.eq([
+//! assert!(it.eq(vec![
 //!     [0.0, 0.0], [0.0, 0.5], [0.0, 1.0], [0.0, 1.5],
 //!     [0.5, 0.0], [0.5, 0.5], [0.5, 1.0], [0.5, 1.5],
 //! ]));
@@ -91,7 +88,7 @@
 //! // from 0.0 up to 1.0 in the x direction stepping by 0.5 each time,
 //! // and 0.0 up to 2.0 in the y direction stepping by 1.0 each time
 //! let it = arange_grid([0.0, 0.0]..[1.0, 2.0], [0.5, 1.0]);
-//! assert!(it.eq([
+//! assert!(it.eq(vec![
 //!     [0.0, 0.0], [0.0, 1.0],
 //!     [0.5, 0.0], [0.5, 1.0],
 //! ]));
@@ -106,18 +103,18 @@
 //!
 //! // From 1.0 up to and including 1000.0, taking 4 logarithmic steps
 //! let it = log_space(1.0..=1000.0, 4);
-//! let expected: [f64; 4] = [1.0, 10.0, 100.0, 1000.0];
+//! let expected: Vec<f64> = vec![1.0, 10.0, 100.0, 1000.0];
 //!
 //! assert!(zip_eq(it, expected).all(|(x, y)| (x-y).abs() < 1e-10));
 //!
 //! // From 1.0 up to 1000.0, taking 3 logarithmic steps
 //! let it = log_space(1.0..1000.0, 3);
-//! let expected: [f64; 3] = [1.0, 10.0, 100.0];
+//! let expected: Vec<f64> = vec![1.0, 10.0, 100.0];
 //!
 //! assert!(zip_eq(it, expected).all(|(x, y)| (x-y).abs() < 1e-10));
 //! ```
 
-#![no_std]
+#![cfg_attr(not(test), no_std)]
 
 mod arange;
 mod arange_grid;
